#pragma once

void nextFullPerm(int *const myArray, int maxInd);
void nextPartialPerm(int *const myArray, int m1, int maxInd);
